@@ -334,3 +334,44 @@ def collocation(corpusquery='norge', word='arbeid', before=5, after=0):
     }
     r = requests.post(BASE_URL + "/urncolldist", json=params)
     return pd.read_json(r.text)
+
+
+import requests
+
+# Norwegian word bank
+def word_variant(word, form, lang = 'nob'):
+    """ Find alternative form for a given word form, e.g. word_variant('spiste', 'pres-part') """
+    r = requests.get(f"{BASE_URL}/variant_form", params={'word':word, 'form':form, 'lang':lang})
+    return r.json()
+
+def word_paradigm(word, lang = 'nob'):
+    """ Find paradigm form for a word  """
+    r = requests.get(f"{BASE_URL}/paradigm", params = {'word': word, 'lang':lang})
+
+    return r.json()
+
+def word_paradigm_many(wordlist, lang = 'nob'):
+    """ Find alternative form for a list words """
+    r = requests.post(f"{BASE_URL}/paradigms", json = {'words': wordlist, 'lang':lang})
+    return r.json()
+
+
+def word_form(word, lang = 'nob'):
+    """ Find alternative form for a given word form, e.g. word_variant('spiste', 'pres-part') """
+    r = requests.get(f"{BASE_URL}/word_form", params = {'word': word, 'lang':lang})
+    return r.json()
+
+def word_form_many(wordlist, lang = 'nob'):
+    """ Find alternative forms for a list of words """
+    r = requests.post(f"{BASE_URL}/word_forms", json = {'words': wordlist, 'lang':lang})
+    return r.json()
+
+def word_lemma(word, lang = 'nob'):
+    """ Find lemma form for a given word form """
+    r = requests.get(f"{BASE_URL}/word_lemma", params = {'word': word, 'lang':lang})
+    return r.json()
+
+def word_lemma_many(wordlist, lang = 'nob'):
+    """ Find lemma form for a given word form """
+    r = requests.post(f"{BASE_URL}/word_lemmas", json = {'words': wordlist, 'lang':lang})
+    return r.json()
\ No newline at end of file
